class TextColor:
	BLACK = 0
	DARK_BLUE = 1	
	DARK_GREEN = 2
	DARK_CYAN = 3
	DARK_RED = 4
	DARK_MAGENTA = 5
	DARK_YELLOW = 6
	LIGHT_GRAY = 7
	GRAY = 8
	BLUE = 9
	GREEN = 10
	CYAN = 11
	RED = 12
	MAGENTA = 13
	YELLOW = 14
	WHITE = 15
